#!/bin/bash

RELEASE=$1
CHART=$2
VERSION_FLAG=$3
VERSION=$4
VALUES_FLAG=$5
VALUES_FILE=$6

if [[ -z "${RELEASE}" ]]
then
    echo "Fix Helm 3 release metadata."
    echo "Usage: fix-helm-2to3-app.sh <customer-app>"
    exit 0
fi

APP=$(echo ${RELEASE} | cut -f2 -d"-")
# Check if it is a JFrog platform app
if [[ ( "${APP}" == "artifactory" ) || ( "${APP}" == "distribution" ) || ( "${APP}" == "jfmc" ) || ( "${APP}" == "pipelines" ) || ( "${APP}" == "xray" ) ]]
then
    echo
    echo "Running Helm 3 release data fix for ${RELEASE}"
else
    echo
    echo "Running Helm 3 release data fix for ${RELEASE}"
    echo "Nothing to do for ${RELEASE}, skipping..."
    exit 0
fi

K8S_OBJECTS=( ingress service statefulset secret configmap role rolebinding hpa pvc NetworkPolicy PodDisruptionBudget serviceaccount )
NAMESPACE=$(echo ${RELEASE} | cut -f1 -d"-")
CUSTOMER=${NAMESPACE}

# Check if the new install
VALIDATE_RELEASE=$(kubectl -n ${NAMESPACE} get sts | grep ${RELEASE} | head -1)
if [[ -z "${VALIDATE_RELEASE}" ]]
then
    echo "New install for ${RELEASE}, skipping fixes..."
    exit 0
fi

# Add Helm 3 required label and annotations
echo
# Check if the label exists
VALIDATE_LABEL=$(kubectl -n ${NAMESPACE} get sts -l "app.kubernetes.io/managed-by=Helm" | grep ${RELEASE})
if [[ ! -z "${VALIDATE_LABEL}" ]]
then
    echo "Helm 3 label is set for ${RELEASE}, skipping fixes..."
    exit 0
fi

for i in "${K8S_OBJECTS[@]}"
do
    echo "Updating ${i} ..."
    if [[ "${RELEASE}" == *"pipelines"* ]]
    then
        kubectl -n ${NAMESPACE} label ${i} -l "release=${RELEASE}" "app.kubernetes.io/managed-by=Helm" --overwrite
        kubectl -n ${NAMESPACE} label ${i} -l "app.kubernetes.io/instance=${RELEASE}" "app.kubernetes.io/managed-by=Helm" --overwrite
        kubectl -n ${NAMESPACE} annotate ${i} -l "release=${RELEASE}" "meta.helm.sh/release-name=${RELEASE}" "meta.helm.sh/release-namespace=${NAMESPACE}" --overwrite
        kubectl -n ${NAMESPACE} annotate ${i} -l "app.kubernetes.io/instance=${RELEASE}" "meta.helm.sh/release-name=${RELEASE}" "meta.helm.sh/release-namespace=${NAMESPACE}" --overwrite
        echo
    else
        kubectl -n ${NAMESPACE} label ${i} -l "release=${RELEASE}" "app.kubernetes.io/managed-by=Helm" --overwrite
        kubectl -n ${NAMESPACE} annotate ${i} -l "release=${RELEASE}" "meta.helm.sh/release-name=${RELEASE}" "meta.helm.sh/release-namespace=${NAMESPACE}" --overwrite
        echo
    fi
done
