#!/bin/bash

RELEASE=$1
CHART=$2
VERSION_FLAG=$3
VERSION=$4
VALUES_FLAG=$5
VALUES_FILE=$6

if [[ -z "${RELEASE}" ]]
then
    echo "Fix Artifactory upgrade."
    echo "Usage: fix-helm-art-upgrade.sh <customer>-artifactory"
    exit 0
fi

APP=$(echo ${RELEASE} | cut -f2 -d"-")
NAMESPACE=$(echo ${RELEASE} | cut -f1 -d"-")

echo
echo "Running Helm Artifactory upgrade fix for ${RELEASE} Primary Node StatefulSet."
# Check if it is Artifactory app
if [[ ( "${APP}" == "artifactory" ) ]]
then
    # Set values path
    VALUES_PATH=/opt/jfrog/saas-deployer/helm-values/namespaces/${JFROG_SERVER_ENVIRONMENT}/${NAMESPACE}/artifactory

    echo "Validating Artifactory Primary Node StatefulSet"
    helm3 template --name-template ${RELEASE} ${CHART} --version ${VERSION} -s templates/artifactory-primary-statefulset.yaml -f ${VALUES_FILE} > ${VALUES_PATH}/validate-artifactory-primary-statefulset.yaml
    rm -f ${VALUES_PATH}/validate-artifactory-primary-statefulset.log
    kubectl apply -n ${NAMESPACE} -f ${VALUES_PATH}/validate-artifactory-primary-statefulset.yaml --dry-run=server 2>&1 | tee ${VALUES_PATH}/validate-artifactory-primary-statefulset.log >/dev/null
    VALIDATE_YAML=$(cat ${VALUES_PATH}/validate-artifactory-primary-statefulset.log | grep -w "error when applying patch" )

    # Deleting Artifactory Primary Node StatefulSet
    if [[ ! -z "${VALIDATE_YAML}" ]]
    then
        echo "Deleting Artifactory ${RELEASE}-primary StatefulSet!!!"
        kubectl -n ${NAMESPACE} delete sts ${RELEASE}-primary --force
    else
        echo "Skipping fix for ${RELEASE}-primary StatefulSet"
    fi
else
    echo "Release ${RELEASE} is not Artifactory app, skipping..."
fi
echo
