#!/bin/bash

RELEASE=$1
CHART=$2
VERSION_FLAG=$3
VERSION=$4
VALUES_FLAG=$5
VALUES_FILE=$6

if [[ -z "${RELEASE}" ]]
then
    echo "Fix Xray upgrade."
    echo "Usage: fix-helm-xray-upgrade.sh <customer>-xray"
    exit 0
fi

APP=$(echo ${RELEASE} | cut -f2 -d"-")
NAMESPACE=$(echo ${RELEASE} | cut -f1 -d"-")

# Check if it is Xray app
if [[ ( "${APP}" == "xray" ) ]]
then
    echo
    echo "Running Helm Xray upgrade RabbitMQ fix for ${RELEASE}."

    # Check incomming helm release chart version
    if [[ "${VERSION}" == *"103."* ]]
    then
        echo "Incomming helm release chart version: ${VERSION}"
        # Check if the old chart 3.1.x label 'app=rabbitmq-ha' exists
        VALIDATE_STS=$(kubectl -n ${NAMESPACE} get sts -l "app=rabbitmq-ha" | grep ${RELEASE} | awk '{print $1}')
        if [[ "${VALIDATE_STS}" == "" ]]
        then
            # Check if PVC is gp2 type
            VALIDATE_PVC=$(kubectl -n ${NAMESPACE} get pvc | grep ${RELEASE}-rabbitmq-0 | head -1 | awk '{print $6}')
            if [[ ( "${VALIDATE_PVC}" == "gp2" ) ]]
            then
                echo "RabbitMQ PVC type is gp2!!!"
                # Check if RabbitMQ queues are empty
                VALIDATE_RMQ_QUEUES=$(kubectl -n ${NAMESPACE} exec ${RELEASE}-rabbitmq-0 -- rabbitmqctl list_queues | tail -n +4 | awk '{print $2}' | egrep '1|2|3|4|5|6|7|8|9')
                if [[ ( ! -z "${VALIDATE_RMQ_QUEUES}" ) ]]
                then
                    echo "RabbitMQ queues are not empty, keeping gp2 storage!!!"
                    exit 0
                else
                    echo "RabbitMQ queues are empty!!!"
                    echo "Deleting Xray statefulset!!!"
                    kubectl -n ${NAMESPACE} delete sts ${RELEASE} --force
                    echo
                    # Get RabbitMQ statefulset replicas count
                    RMQ_STS_REPLICAS=$(kubectl -n ${NAMESPACE} get sts ${RELEASE}-rabbitmq -o=jsonpath='{.status.replicas}')
                    echo "Deleting RabbitMQ statefulset of ${RELEASE}-rabbitmq!!!"
                    kubectl -n ${NAMESPACE} delete sts ${RELEASE}-rabbitmq --force
                    echo
                    echo "Deleting RabbitMQ PVC/s of ${RELEASE}-rabbitmq!!!"
                    for (( c=0; c<${RMQ_STS_REPLICAS}; c++ ))
                    do
                        kubectl -n ${NAMESPACE} delete pvc data-${RELEASE}-rabbitmq-${c}
                    done
                    # update values-jfrog-saas2.yaml from gp2 to nfs
                    if [ "$(uname)" = "Darwin" ]; then
                        sed -i "" 's/storageClass: "gp2"/storageClass: "nfs"/' ${VALUES_FILE}
                    elif [ "$(uname)" = "Linux" ] ; then
                        sed -i 's/storageClass: "gp2"/storageClass: "nfs"/' ${VALUES_FILE}
                    fi
                    exit 0
                fi
            fi
            echo "Nothing to do, skipping..."
        else
            # Upgrade from chart 3.1.x to 103.x.x
            echo "Deleting RabbitMQ statefulset of ${RELEASE}-rabbitmq-ha!!!"
            kubectl -n ${NAMESPACE} delete sts ${RELEASE}-rabbitmq-ha --force
            echo
        fi
    else
        echo "Helm chart version is 3.1.x one, skipping..."
        echo
    fi
else
    echo
    echo "Running Helm Xray upgrade RabbitMQ fix for ${RELEASE}."
    echo "Release ${RELEASE} is not Xray app, skipping..."
    echo
fi
