#!/bin/bash

RELEASE=$1
SECRET_LIVE_TIME="${2-60}"

if [[ -z "${RELEASE}" ]]
then
    echo "Helm 3 install/upgrade fix for pending release issue."
    echo "Usage: fix-helm3-deploy.sh <customer-app>"
    exit 0
fi

NAMESPACE=$3
if [[ -z "${NAMESPACE}" ]]
then
    echo "Namespace is a mandatory"
    exit 0
fi

echo
echo "Running Helm 3 pending install/upgrade fix for ${RELEASE} for namespace ${NAMESPACE}"

# Release version and secret creation time
SECRET_VERSION="$(helm3 ls --pending -n ${NAMESPACE} --filter "${RELEASE}" | tail -n 1 | grep pending | awk '{print $3}')"
if [[ -z "${SECRET_VERSION}" ]]
then
    echo "Nothing to do for ${RELEASE}, skipping..."
    exit 0
fi

# Secret time
SECRET_TIME="$(helm3 ls --pending -n ${NAMESPACE} --filter "${RELEASE}" -oyaml | grep updated | awk '{print $2,$3}' | cut -d'.' -f1)"

# Current time
CURRENT_TIME="$(date '+%F %X')"

# Convert time to seconds
if [ "$(uname)" = "Darwin" ]; then
    SECRET_TIME_SECS=$(date -j -f '%Y-%m-%d %H:%M:%S' "${SECRET_TIME}" '+%s')
    CURRENT_TIME_SECS=$(date -j -f '%Y-%m-%d %H:%M:%S' "${CURRENT_TIME}" '+%s')
elif [ "$(uname)" = "Linux" ] ; then
    SECRET_TIME_SECS=$(date -d "${SECRET_TIME}" +%s)
    CURRENT_TIME_SECS=$(date -d "${CURRENT_TIME}" +%s)
fi

# A difference in minutes between current and secret creation times
MINUTES_DIFF=$(( ($CURRENT_TIME_SECS - $SECRET_TIME_SECS) / 60 ))

if [[ ${MINUTES_DIFF} < ${SECRET_LIVE_TIME} ]]
then
    echo "Helm 3 release secret sh.helm.release.v1.${RELEASE}.v${SECRET_VERSION} is less than ${SECRET_LIVE_TIME} minutes old, skipping..."
    exit 0
fi

echo "Deleting secret sh.helm.release.v1.${RELEASE}.v${SECRET_VERSION} ..."
kubectl -n ${NAMESPACE} delete secret sh.helm.release.v1.${RELEASE}.v${SECRET_VERSION}
echo
