#!/bin/bash
#set -e

if [ ! -z $1 ]; then
    STARTUP_CMD=$1
else
    # by default start as narcissus-agent
    STARTUP_CMD="narcissus-agent"
fi

prinInfo(){

    local msg=$1
    local type="INFO"
    local current_date=$(date "+%Y%d%m %T")

    echo "[${current_date}] [${type}] $msg"
}

applicationHealthcheck() {
    prinInfo "Running application healthcheck..."

    local healthcheck_api=$1
    local healthcheck_tries=0
    local max_healthcheck_tries=10
    local response="000"

    while [ ${max_healthcheck_tries} -gt ${healthcheck_tries} ] && [[ ${response} != "200" ]]; do
        sleep 2
        response=$(curl -s -L -o /dev/null --connect-timeout 10 --max-time 30 -w "%{http_code}" ${healthcheck_api})
        let "healthcheck_tries=healthcheck_tries+1"
        prinInfo "[${healthcheck_tries}/${max_healthcheck_tries}] API [${healthcheck_api}] response code[${response}]"
    done

    if [ $response == 200 ]; then
        prinInfo "SUCCESS: ${healthcheck_api} returned 200"
    else
        MY_IP=$(dig +short myip.opendns.com @resolver1.opendns.com)
        prinInfo "FAILED: ${healthcheck_api} failed with http code ${response} from IP [${MY_IP}]"
        exit 1
    fi
}

loadKeys(){
    export GPG_TTY=$(tty)
    JFROG_GPG_KEY="/opt/jfrog/saas-deployer/secrets/devopssaas-gpg.pem"
    prinInfo "Loading saas deployer gpg key for decryption processes during deployment [$JFROG_GPG_KEY]"


    if [ ! -f "${JFROG_GPG_KEY}" ]; then
        prinInfo "Could not find GPG key at ${JFROG_GPG_KEY}; Can not proceed!!!"
    fi


    prinInfo "Get gpg_passphrase using jfrog_narcissus_cli with user [${NARCISSUS_USER}]"
    export $(jfrog_narcissus_cli getRegionDetails --region global --param 'withKeys,gpg_passphrase,route53_aws_access_key_id,route53_aws_secret_access_key,environment')

    prinInfo "Import GPG key"
    gpg --batch --pinentry-mode=loopback --passphrase ${gpg_passphrase} --import ${JFROG_GPG_KEY}
}

setBashRc(){
    prinInfo "Set aliases_k8s in .bashrc"
    echo "source /opt/jfrog/saas-deployer/aliases_k8s.sh" >> /root/.bashrc
}

prinInfo "Starting SaaS Deployer"

case ${JFROG_SERVER_ENVIRONMENT} in
    "prod"*|"PROD"*)
        NARCISSUS_URL="https://narcissus.jfrog.com/view/login"
     ;;
     "dev"*|"development"*|"DEV"*)
        NARCISSUS_URL="https://narcissus.jfrogdev.org/view/login"
     ;;
     *)
        NARCISSUS_URL="https://narcissus.jfrog.info/view/login"
     ;;
esac


case ${STARTUP_CMD} in
    "narcissus-agent")
        loadKeys
        setBashRc
        prinInfo "Starting narcissus agent"
        exec /usr/bin/python3 /usr/local/bin/narcissus-agent
    ;;
    *)
        loadKeys
        setBashRc
        prinInfo "Starting ${STARTUP_CMD}"
        ${STARTUP_CMD}
    ;;
esac
